# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/logging/type/log_severity.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&google/logging/type/log_severity.proto\x12\x13google.logging.type\x1a\x1cgoogle/api/annotations.proto*\x82\x01\n\x0bLogSeverity\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\t\n\x05\x44\x45\x42UG\x10\x64\x12\t\n\x04INFO\x10\xc8\x01\x12\x0b\n\x06NOTICE\x10\xac\x02\x12\x0c\n\x07WARNING\x10\x90\x03\x12\n\n\x05\x45RROR\x10\xf4\x03\x12\r\n\x08\x43RITICAL\x10\xd8\x04\x12\n\n\x05\x41LERT\x10\xbc\x05\x12\x0e\n\tEMERGENCY\x10\xa0\x06\x42\xbe\x01\n\x17\x63om.google.logging.typeB\x10LogSeverityProtoP\x01Z8google.golang.org/genproto/googleapis/logging/type;ltype\xaa\x02\x19Google.Cloud.Logging.Type\xca\x02\x19Google\\Cloud\\Logging\\Type\xea\x02\x1cGoogle::Cloud::Logging::Typeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.logging.type.log_severity_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.google.logging.typeB\020LogSeverityProtoP\001Z8google.golang.org/genproto/googleapis/logging/type;ltype\252\002\031Google.Cloud.Logging.Type\312\002\031Google\\Cloud\\Logging\\Type\352\002\034Google::Cloud::Logging::Type'
  _globals['_LOGSEVERITY']._serialized_start=94
  _globals['_LOGSEVERITY']._serialized_end=224
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/header_mutation/v3/header_mutation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.common.mutation_rules.v3 import mutation_rules_pb2 as envoy_dot_config_dot_common_dot_mutation__rules_dot_v3_dot_mutation__rules__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFenvoy/extensions/filters/http/header_mutation/v3/header_mutation.proto\x12\x30\x65nvoy.extensions.filters.http.header_mutation.v3\x1a:envoy/config/common/mutation_rules/v3/mutation_rules.proto\x1a\x1dudpa/annotations/status.proto\"\xb0\x01\n\tMutations\x12P\n\x11request_mutations\x18\x01 \x03(\x0b\x32\x35.envoy.config.common.mutation_rules.v3.HeaderMutation\x12Q\n\x12response_mutations\x18\x02 \x03(\x0b\x32\x35.envoy.config.common.mutation_rules.v3.HeaderMutation\"h\n\x16HeaderMutationPerRoute\x12N\n\tmutations\x18\x01 \x01(\x0b\x32;.envoy.extensions.filters.http.header_mutation.v3.Mutations\"\x8d\x01\n\x0eHeaderMutation\x12N\n\tmutations\x18\x01 \x01(\x0b\x32;.envoy.extensions.filters.http.header_mutation.v3.Mutations\x12+\n#most_specific_header_mutations_wins\x18\x02 \x01(\x08\x42\xca\x01\n>io.envoyproxy.envoy.extensions.filters.http.header_mutation.v3B\x13HeaderMutationProtoP\x01Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/header_mutation/v3;header_mutationv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.header_mutation.v3.header_mutation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>io.envoyproxy.envoy.extensions.filters.http.header_mutation.v3B\023HeaderMutationProtoP\001Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/header_mutation/v3;header_mutationv3\272\200\310\321\006\002\020\002'
  _globals['_MUTATIONS']._serialized_start=216
  _globals['_MUTATIONS']._serialized_end=392
  _globals['_HEADERMUTATIONPERROUTE']._serialized_start=394
  _globals['_HEADERMUTATIONPERROUTE']._serialized_end=498
  _globals['_HEADERMUTATION']._serialized_start=501
  _globals['_HEADERMUTATION']._serialized_end=642
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/aws_request_signing/v2alpha/aws_request_signing.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNenvoy/config/filter/http/aws_request_signing/v2alpha/aws_request_signing.proto\x12\x34\x65nvoy.config.filter.http.aws_request_signing.v2alpha\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"a\n\x11\x41wsRequestSigning\x12\x1d\n\x0cservice_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x17\n\x06region\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x14\n\x0chost_rewrite\x18\x03 \x01(\tB\xff\x01\nBio.envoyproxy.envoy.config.filter.http.aws_request_signing.v2alphaB\x16\x41wsRequestSigningProtoP\x01Z[github.com/envoyproxy/go-control-plane/envoy/config/filter/http/aws_request_signing/v2alpha\xf2\x98\xfe\x8f\x05\x36\x12\x34\x65nvoy.extensions.filters.http.aws_request_signing.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.http.aws_request_signing.v2alpha.aws_request_signing_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nBio.envoyproxy.envoy.config.filter.http.aws_request_signing.v2alphaB\026AwsRequestSigningProtoP\001Z[github.com/envoyproxy/go-control-plane/envoy/config/filter/http/aws_request_signing/v2alpha\362\230\376\217\0056\0224envoy.extensions.filters.http.aws_request_signing.v3\272\200\310\321\006\002\020\001'
  _AWSREQUESTSIGNING.fields_by_name['service_name']._options = None
  _AWSREQUESTSIGNING.fields_by_name['service_name']._serialized_options = b'\372B\004r\002 \001'
  _AWSREQUESTSIGNING.fields_by_name['region']._options = None
  _AWSREQUESTSIGNING.fields_by_name['region']._serialized_options = b'\372B\004r\002 \001'
  _globals['_AWSREQUESTSIGNING']._serialized_start=224
  _globals['_AWSREQUESTSIGNING']._serialized_end=321
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1beta1/expr.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api.expr.v1beta1 import source_pb2 as google_dot_api_dot_expr_dot_v1beta1_dot_source__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"google/api/expr/v1beta1/expr.proto\x12\x17google.api.expr.v1beta1\x1a$google/api/expr/v1beta1/source.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x8b\x01\n\nParsedExpr\x12+\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.Expr\x12\x38\n\x0bsource_info\x18\x03 \x01(\x0b\x32#.google.api.expr.v1beta1.SourceInfo\x12\x16\n\x0esyntax_version\x18\x04 \x01(\t\"\xab\n\n\x04\x45xpr\x12\n\n\x02id\x18\x02 \x01(\x05\x12\x38\n\x0cliteral_expr\x18\x03 \x01(\x0b\x32 .google.api.expr.v1beta1.LiteralH\x00\x12\x39\n\nident_expr\x18\x04 \x01(\x0b\x32#.google.api.expr.v1beta1.Expr.IdentH\x00\x12;\n\x0bselect_expr\x18\x05 \x01(\x0b\x32$.google.api.expr.v1beta1.Expr.SelectH\x00\x12\x37\n\tcall_expr\x18\x06 \x01(\x0b\x32\".google.api.expr.v1beta1.Expr.CallH\x00\x12=\n\tlist_expr\x18\x07 \x01(\x0b\x32(.google.api.expr.v1beta1.Expr.CreateListH\x00\x12\x41\n\x0bstruct_expr\x18\x08 \x01(\x0b\x32*.google.api.expr.v1beta1.Expr.CreateStructH\x00\x12I\n\x12\x63omprehension_expr\x18\t \x01(\x0b\x32+.google.api.expr.v1beta1.Expr.ComprehensionH\x00\x1a\x15\n\x05Ident\x12\x0c\n\x04name\x18\x01 \x01(\t\x1aZ\n\x06Select\x12.\n\x07operand\x18\x01 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.Expr\x12\r\n\x05\x66ield\x18\x02 \x01(\t\x12\x11\n\ttest_only\x18\x03 \x01(\x08\x1at\n\x04\x43\x61ll\x12-\n\x06target\x18\x01 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.Expr\x12\x10\n\x08\x66unction\x18\x02 \x01(\t\x12+\n\x04\x61rgs\x18\x03 \x03(\x0b\x32\x1d.google.api.expr.v1beta1.Expr\x1a=\n\nCreateList\x12/\n\x08\x65lements\x18\x01 \x03(\x0b\x32\x1d.google.api.expr.v1beta1.Expr\x1a\xf6\x01\n\x0c\x43reateStruct\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x41\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x30.google.api.expr.v1beta1.Expr.CreateStruct.Entry\x1a\x94\x01\n\x05\x45ntry\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x13\n\tfield_key\x18\x02 \x01(\tH\x00\x12\x30\n\x07map_key\x18\x03 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.ExprH\x00\x12,\n\x05value\x18\x04 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.ExprB\n\n\x08key_kind\x1a\xb0\x02\n\rComprehension\x12\x10\n\x08iter_var\x18\x01 \x01(\t\x12\x31\n\niter_range\x18\x02 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.Expr\x12\x10\n\x08\x61\x63\x63u_var\x18\x03 \x01(\t\x12\x30\n\taccu_init\x18\x04 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.Expr\x12\x35\n\x0eloop_condition\x18\x05 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.Expr\x12\x30\n\tloop_step\x18\x06 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.Expr\x12-\n\x06result\x18\x07 \x01(\x0b\x32\x1d.google.api.expr.v1beta1.ExprB\x0b\n\texpr_kind\"\xd8\x01\n\x07Literal\x12\x30\n\nnull_value\x18\x01 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00\x12\x14\n\nbool_value\x18\x02 \x01(\x08H\x00\x12\x15\n\x0bint64_value\x18\x03 \x01(\x03H\x00\x12\x16\n\x0cuint64_value\x18\x04 \x01(\x04H\x00\x12\x16\n\x0c\x64ouble_value\x18\x05 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x06 \x01(\tH\x00\x12\x15\n\x0b\x62ytes_value\x18\x07 \x01(\x0cH\x00\x42\x0f\n\rconstant_kindBj\n\x1b\x63om.google.api.expr.v1beta1B\tExprProtoP\x01Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\xf8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.expr.v1beta1.expr_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033com.google.api.expr.v1beta1B\tExprProtoP\001Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\370\001\001'
  _globals['_PARSEDEXPR']._serialized_start=132
  _globals['_PARSEDEXPR']._serialized_end=271
  _globals['_EXPR']._serialized_start=274
  _globals['_EXPR']._serialized_end=1597
  _globals['_EXPR_IDENT']._serialized_start=734
  _globals['_EXPR_IDENT']._serialized_end=755
  _globals['_EXPR_SELECT']._serialized_start=757
  _globals['_EXPR_SELECT']._serialized_end=847
  _globals['_EXPR_CALL']._serialized_start=849
  _globals['_EXPR_CALL']._serialized_end=965
  _globals['_EXPR_CREATELIST']._serialized_start=967
  _globals['_EXPR_CREATELIST']._serialized_end=1028
  _globals['_EXPR_CREATESTRUCT']._serialized_start=1031
  _globals['_EXPR_CREATESTRUCT']._serialized_end=1277
  _globals['_EXPR_CREATESTRUCT_ENTRY']._serialized_start=1129
  _globals['_EXPR_CREATESTRUCT_ENTRY']._serialized_end=1277
  _globals['_EXPR_COMPREHENSION']._serialized_start=1280
  _globals['_EXPR_COMPREHENSION']._serialized_end=1584
  _globals['_LITERAL']._serialized_start=1600
  _globals['_LITERAL']._serialized_end=1816
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v3/grpc_method_list.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+envoy/config/core/v3/grpc_method_list.proto\x12\x14\x65nvoy.config.core.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xec\x01\n\x0eGrpcMethodList\x12>\n\x08services\x18\x01 \x03(\x0b\x32,.envoy.config.core.v3.GrpcMethodList.Service\x1aq\n\x07Service\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1e\n\x0cmethod_names\x18\x02 \x03(\tB\x08\xfa\x42\x05\x92\x01\x02\x08\x01:/\x9a\xc5\x88\x1e*\n(envoy.api.v2.core.GrpcMethodList.Service:\'\x9a\xc5\x88\x1e\"\n envoy.api.v2.core.GrpcMethodListB\x87\x01\n\"io.envoyproxy.envoy.config.core.v3B\x13GrpcMethodListProtoP\x01ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.core.v3.grpc_method_list_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"io.envoyproxy.envoy.config.core.v3B\023GrpcMethodListProtoP\001ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\272\200\310\321\006\002\020\002'
  _GRPCMETHODLIST_SERVICE.fields_by_name['name']._options = None
  _GRPCMETHODLIST_SERVICE.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _GRPCMETHODLIST_SERVICE.fields_by_name['method_names']._options = None
  _GRPCMETHODLIST_SERVICE.fields_by_name['method_names']._serialized_options = b'\372B\005\222\001\002\010\001'
  _GRPCMETHODLIST_SERVICE._options = None
  _GRPCMETHODLIST_SERVICE._serialized_options = b'\232\305\210\036*\n(envoy.api.v2.core.GrpcMethodList.Service'
  _GRPCMETHODLIST._options = None
  _GRPCMETHODLIST._serialized_options = b'\232\305\210\036\"\n envoy.api.v2.core.GrpcMethodList'
  _globals['_GRPCMETHODLIST']._serialized_start=161
  _globals['_GRPCMETHODLIST']._serialized_end=397
  _globals['_GRPCMETHODLIST_SERVICE']._serialized_start=243
  _globals['_GRPCMETHODLIST_SERVICE']._serialized_end=356
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/retry/omit_host_metadata/v2/omit_host_metadata_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHenvoy/config/retry/omit_host_metadata/v2/omit_host_metadata_config.proto\x12(envoy.config.retry.omit_host_metadata.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"M\n\x16OmitHostMetadataConfig\x12\x33\n\x0emetadata_match\x18\x01 \x01(\x0b\x32\x1b.envoy.api.v2.core.MetadataB\xfe\x01\n6io.envoyproxy.envoy.config.retry.omit_host_metadata.v2B\x1bOmitHostMetadataConfigProtoP\x01Zdgithub.com/envoyproxy/go-control-plane/envoy/config/retry/omit_host_metadata/v2;omit_host_metadatav2\xf2\x98\xfe\x8f\x05\x33\x12\x31\x65nvoy.extensions.retry.host.omit_host_metadata.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.retry.omit_host_metadata.v2.omit_host_metadata_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n6io.envoyproxy.envoy.config.retry.omit_host_metadata.v2B\033OmitHostMetadataConfigProtoP\001Zdgithub.com/envoyproxy/go-control-plane/envoy/config/retry/omit_host_metadata/v2;omit_host_metadatav2\362\230\376\217\0053\0221envoy.extensions.retry.host.omit_host_metadata.v3\272\200\310\321\006\002\020\001'
  _globals['_OMITHOSTMETADATACONFIG']._serialized_start=211
  _globals['_OMITHOSTMETADATACONFIG']._serialized_end=288
# @@protoc_insertion_point(module_scope)
